.. _power_atlas:

Power 2011 atlas
================

Access
------
See :func:`nilearn.datasets.fetch_coords_power_2011`.

Notes
-----
264 ROIs obtained by meta-analysis.

See :footcite:t:`Power2011`.

Content
-------
    :'rois': Coordinates of ROIs in :term:`MNI` space.

References
----------

.. footbibliography::

License
-------
unknown
